@@ -29,6 +29,7 @@ class TerraformParser(object):
             '1.1.',
             '1.2.',
             '1.3.',
+            '1.4.',
         )
         self.supported_format_versions = [
             '0.1',
@@ -577,6 +578,7 @@ class TerraformParser(object):
                 self.cache.set('mounted_resources', self.resources)
                 self.cache.set('resources_raw', self.resources_raw)
                 self.cache.set('type_to_after_unknown_properties', self.type_to_after_unknown_properties)
+                self.cache.close()
 
         self._distribute_providers()
 
